@@ -219,16 +219,6 @@ lj_entry_load_metadata(LJEntry *entry,
 }
 
 #ifdef HAVE_LIBXML
-static xmlNodePtr
-addtextchildenc(xmlDocPtr doc, xmlNodePtr parent, char *name, char *val) {
-	xmlChar *enc;
-	xmlNodePtr node;
-	enc = xmlEncodeEntitiesReentrant(doc, BAD_CAST val);
-	node = xmlNewTextChild(parent, NULL, BAD_CAST name, BAD_CAST val);
-	xmlFree(enc);
-	return node;
-}
-
 #define XML_ENTRY_META_GET(A)                                          \
     if ((!xmlStrcmp(cur->name, BAD_CAST #A))) {	                       \
         entry->A = (char*)xmlNodeListGetString(doc, cur->xmlChildrenNode, 1); \
@@ -236,7 +226,7 @@ addtextchildenc(xmlDocPtr doc, xmlNodePtr parent, char *name, char *val) {
 
 #define XML_ENTRY_META_SET(A)                     \
 	if (entry->A)                                 \
-		addtextchildenc(doc, root, #A, entry->A);
+		xmlNewTextChild(root, NULL, BAD_CAST #A, BAD_CAST entry->A);
 
 void*
 lj_entry_to_xml_node(LJEntry *entry, void* doc) {
@@ -254,7 +244,7 @@ lj_entry_to_xml_node(LJEntry *entry, void* doc) {
 	XML_ENTRY_META_SET(event);
 	if (entry->mood || entry->moodid) {
 		if (entry->mood)
-			node = addtextchildenc(doc, root, "mood", entry->mood);
+			node = xmlNewTextChild(root, NULL, BAD_CAST "mood", BAD_CAST entry->mood);
 		else
 			node = xmlNewChild(root, NULL, BAD_CAST "mood", NULL);
 
@@ -283,7 +273,7 @@ lj_entry_to_xml_node(LJEntry *entry, void* doc) {
 	}
 	if (entry->time.tm_year) {
 		char *ljdate = lj_tm_to_ljdate(&entry->time);
-		addtextchildenc(doc, root, "time", ljdate);
+		xmlNewTextChild(root, NULL, BAD_CAST "time", BAD_CAST ljdate);
 		g_free(ljdate);
 	}
 	if (entry->security.type != LJ_SECURITY_PUBLIC) {
@@ -371,10 +361,18 @@ lj_entry_new_from_result(LJResult *result, int i) {
 	anum = lj_result_getf(result, "events_%d_anum", i);
 	if (anum) entry->anum = atoi(anum);
 	lj_ljdate_to_tm(lj_result_getf(result, "events_%d_eventtime", i), &entry->time);
+
 	entry->event = lj_urldecode(lj_result_getf(result, "events_%d_event", i));
-	verify_utf8(&entry->event);
+	if (!verify_utf8(&entry->event))
+		g_warning("Bad UTF-8 in event of itemid %d.\n", entry->itemid); 
+	/* http://www.livejournal.com/community/logjam/113710.html */
+	if (!entry->event)
+		entry->event = g_strdup("");
+
 	entry->subject = g_strdup(lj_result_getf(result, "events_%d_subject", i));
-	verify_utf8(&entry->subject);
+	if (!verify_utf8(&entry->subject))
+		g_warning("Bad UTF-8 in subject of itemid %d.\n", entry->itemid); 
+
 	lj_security_from_strings(&entry->security, 
 			lj_result_getf(result, "events_%d_security", i),
 			lj_result_getf(result, "events_%d_allowmask", i));
@@ -513,6 +511,11 @@ lj_entry_load_from_xml_node(LJEntry *entry, xmlDocPtr doc, xmlNodePtr node) {
 
 		cur = cur->next;
 	}
+	/* http://www.livejournal.com/community/logjam/113710.html */
+	if (!entry->subject)
+		entry->subject = g_strdup("");
+	if (!entry->event)
+		entry->event = g_strdup("");
 }
 
 LJEntry*
