@@ -52,7 +52,7 @@ typedef struct _LJEntry {
 	char *event;
 
 	int moodid;  /* a moodid is only meaningful in the context of a particular LJServer. */
-	char *mood, *music, *pickeyword;
+	char *mood, *music, *taglist, *pickeyword;
 	gboolean preformatted;
 	gboolean backdated;
 	LJCommentsType comments;
@@ -84,8 +84,8 @@ LJEntry*   lj_entry_new_single_from_result(LJResult *result, GError **err);
 LJEntry*   lj_entry_copy                 (LJEntry *e);
 void       lj_entry_free                 (LJEntry *e);
 
-char*      lj_entry_make_summary         (LJEntry *entry);
-char*      lj_get_summary                (char *subject, char *event);
+const char* lj_entry_make_summary         (LJEntry *entry);
+const char* lj_get_summary               (const char *subject, const char *event);
 void       lj_entry_set_request_fields   (LJEntry *entry, LJRequest *request);
 
 xmlNodePtr lj_entry_to_xml_node          (LJEntry *entry, xmlDocPtr doc);
