@@ -37,10 +37,11 @@ needsescape(char c) {
 }
 
 char*
-lj_urlencode(unsigned char *string) {
+lj_urlencode(const char *string) {
 	int escapecount = 0;
-	unsigned char *src, *dest;
-	unsigned char *newstr;
+	const char *src;
+	char *dest;
+	char *newstr;
 	
 	char hextable[] = { '0', '1', '2', '3', '4', '5', '6', '7',
 	                    '8', '9', 'A', 'B', 'C', 'D', 'E', 'F'  };
@@ -50,15 +51,16 @@ lj_urlencode(unsigned char *string) {
 	for (src = string; *src != 0; src++) 
 		if (needsescape(*src)) escapecount++;
 	
-	newstr = g_new(char, strlen(string) - escapecount + (escapecount * 3) + 1);
+	newstr = g_new(char, (src-string) - escapecount + (escapecount * 3) + 1);
 	
 	src = string;
 	dest = newstr;
 	while (*src != 0) {
 		if (needsescape(*src)) {
+			unsigned char c = *src;
 			*dest++ = '%';
-			*dest++ = hextable[*src >> 4];
-			*dest++ = hextable[*src & 0x0F];
+			*dest++ = hextable[c >> 4];
+			*dest++ = hextable[c & 0x0F];
 			src++;
 		} else {
 			*dest++ = *src++;
@@ -69,11 +71,12 @@ lj_urlencode(unsigned char *string) {
 	return newstr;
 }
 
-unsigned char* 
-lj_urldecode(char *string) {
+char* 
+lj_urldecode(const char *string) {
 	int destlen = 0;
-	unsigned char *src, *dest;
-	unsigned char *newstr;
+	const char *src;
+	char *dest;
+	char *newstr;
 	
 	if (string == NULL) return NULL;
 
@@ -202,7 +205,7 @@ lj_request_new_without_auth(LJUser *user, const char *mode) {
 LJRequest*
 lj_request_new(LJUser *user, const char *mode) {
 	LJRequest *request = lj_request_new_without_auth(user, mode);
-	unsigned char buf[33];
+	char buf[33];
 	lj_request_add(request, "user", user->username);
 	lj_md5_hash(user->password, buf);
 	lj_request_add(request, "hpassword", buf);
