@@ -13,9 +13,8 @@
 #include "spawn.h"
 #include "menu.h"
 #include "settings.h"
-#include "util.h"
 
-#include "network-throbber.h"
+#include "throbber.h"
 #include "checkfriends.h"
 
 struct _CFFloat {
@@ -48,17 +47,17 @@ cf_float_update(CFFloat *cff, CFState state) {
 	
 	switch (state) {
 		case CF_DISABLED:
-			net_throbber_stop(NET_THROBBER(cff->throbber));
-			net_throbber_reset(NET_THROBBER(cff->throbber));
+			throbber_stop(THROBBER(cff->throbber));
+			throbber_reset(THROBBER(cff->throbber));
 			tip_text    = _("Check Friends disabled");
 			break;
 		case CF_ON:
-			net_throbber_stop(NET_THROBBER(cff->throbber));
-			net_throbber_reset(NET_THROBBER(cff->throbber));
+			throbber_stop(THROBBER(cff->throbber));
+			throbber_reset(THROBBER(cff->throbber));
 			tip_text    = _("No new entries in your friends view");
 			break;
 		case CF_NEW:
-			net_throbber_start(NET_THROBBER(cff->throbber));
+			throbber_start(THROBBER(cff->throbber));
 			tip_text    = _("There are new entries in your friends view");
 			break;
 	}
@@ -215,7 +214,7 @@ cf_float_new(CFMgr *cfm) {
 	g_signal_connect(G_OBJECT(cff->box), "button_press_event",
 			G_CALLBACK(clicked_cb), cff);
 
-	cff->throbber = net_throbber_new();
+	cff->throbber = throbber_new();
 	gtk_container_add(GTK_CONTAINER(cff->box), cff->throbber);
 
 	if (!conf.options.cffloat_decorate) {
