@@ -9,10 +9,11 @@
 #include <libxml/parser.h>
 #include <libxml/tree.h>
 
-#include <glib.h>
+#include <string.h>
+
+#include "glib-all.h"
 
 #include <stdlib.h> /* atoi */
-#include "util.h"
 #include "conf.h"
 #include "conf_xml.h"
 #include "jam_xml.h"
@@ -23,7 +24,7 @@
 #endif
 
 #define xmlGetString jam_xmlGetString
-#define xmlAddTN(node, name, value) xmlNewTextChild(node, NULL, name, value)
+#define xmlAddTN(node, name, value) xmlNewTextChild(node, NULL, BAD_CAST name, BAD_CAST value)
 
 /*static xmlNodePtr
 ljxmlAddTxt(xmlNodePtr node, char *name, char *val) {
@@ -126,15 +127,15 @@ parsegeometry(Geometry *geom, xmlDocPtr doc, xmlNodePtr node) {
 
 static void
 parsegeometries(Configuration *c, xmlDocPtr doc, xmlNodePtr node) {
-	char *window;
+	xmlChar *window;
 	int i;
 	for (node = node->xmlChildrenNode; node != NULL; node = node->next) {
-		if (xmlStrcmp(node->name, "geometry") == 0) {
-			window = xmlGetProp(node, "window");
+		if (xmlStrcmp(node->name, BAD_CAST "geometry") == 0) {
+			window = xmlGetProp(node, BAD_CAST "window");
 			if (!window) continue;
 
 			for (i = 0; i < GEOM_COUNT; i++) {
-				if (g_ascii_strcasecmp(window, geometry_names[i]) == 0) {
+				if (g_ascii_strcasecmp((char*)window, geometry_names[i]) == 0) {
 					parsegeometry(&c->geometries[i], doc, node);
 					break;
 				}
@@ -158,7 +159,7 @@ static void
 parseshowmeta(Options *options, xmlDocPtr doc, xmlNodePtr node) {
 	JamViewMeta meta;
 	for (node = node->xmlChildrenNode; node != NULL; node = node->next) {
-		if (jam_view_meta_from_name(node->name, &meta))
+		if (jam_view_meta_from_name((char*)node->name, &meta))
 			options->showmeta[meta] = TRUE;
 	}
 }
@@ -201,10 +202,10 @@ parseoptions(Configuration *c, xmlDocPtr doc, xmlNodePtr node) {
 
 static void
 parsesecurity(Configuration *c, xmlDocPtr doc, xmlNodePtr node) {
-	char *typestr;
-	typestr = xmlGetProp(node, "type");
+	xmlChar *typestr;
+	typestr = xmlGetProp(node, BAD_CAST "type");
 	if (!typestr) return;
-	lj_security_from_strings(&c->defaultsecurity, typestr, NULL);
+	lj_security_from_strings(&c->defaultsecurity, (char*)typestr, NULL);
 	xmlFree(typestr);
 }
 
@@ -287,8 +288,8 @@ conf_read(Configuration *c, char *path) {
 
 static void
 writegeometry(Geometry *geometry, char *name, xmlNodePtr node) {
-	node = xmlNewChild(node, NULL, "geometry", NULL);
-	xmlSetProp(node, "window", name);
+	node = xmlNewChild(node, NULL, BAD_CAST "geometry", NULL);
+	xmlSetProp(node, BAD_CAST "window", BAD_CAST name);
 	jam_xmlAddInt(node, "x", geometry->x);
 	jam_xmlAddInt(node, "y", geometry->y);
 	jam_xmlAddInt(node, "width",  geometry->width);
@@ -300,18 +301,18 @@ writegeometry(Geometry *geometry, char *name, xmlNodePtr node) {
 #ifdef HAVE_GTK
 static void
 writeshowmeta(Options *options, xmlNodePtr node) {
-	xmlNodePtr showmeta = xmlNewChild(node, NULL, "showmeta", NULL);
+	xmlNodePtr showmeta = xmlNewChild(node, NULL, BAD_CAST "showmeta", NULL);
 	int i;
 	for (i = JAM_VIEW_META_FIRST; i <= JAM_VIEW_META_LAST; i++) {
 		if (options->showmeta[i])
-			xmlNewChild(showmeta, NULL, jam_view_meta_to_name(i), NULL);
+			xmlNewChild(showmeta, NULL, BAD_CAST jam_view_meta_to_name(i), NULL);
 	}
 }
 #endif /* HAVE_GTK */
 
 static void
 writeoptions(Options *options, xmlNodePtr node) {
-#define WRITEOPTION(x) if (options->x) xmlNewChild(node, NULL, #x, NULL);
+#define WRITEOPTION(x) if (options->x) xmlNewChild(node, NULL, BAD_CAST #x, NULL);
 	WRITEOPTION(netdump);
 	WRITEOPTION(nofork);
 	WRITEOPTION(useproxy);
@@ -345,7 +346,7 @@ conf_write(Configuration *c, char *base) {
 	char *path;
 
 	jam_xmlNewDoc(&doc, &root, "configuration");
-	xmlSetProp(root, "version", "1");
+	xmlSetProp(root, BAD_CAST "version", BAD_CAST "1");
 
 	for (l = c->hosts; l != NULL; l = l->next) {
 		if (!jam_host_write(l->data, &err)) {
@@ -358,14 +359,14 @@ conf_write(Configuration *c, char *base) {
 	if (c->lasthost)
 		xmlAddTN(root, "currentserver", c->lasthost->name);
 
-	node = xmlNewChild(root, NULL, "geometries", NULL);
+	node = xmlNewChild(root, NULL, BAD_CAST "geometries", NULL);
 	for (i = 0; i < GEOM_COUNT; i++) {
 		if (c->geometries[i].width > 0) {
 			writegeometry(&c->geometries[i], geometry_names[i], node);
 		}
 	}
 
-	node = xmlNewChild(root, NULL, "options", NULL);
+	node = xmlNewChild(root, NULL, BAD_CAST "options", NULL);
 	writeoptions(&c->options, node);
 
 	if (c->uifont)
@@ -379,7 +380,7 @@ conf_write(Configuration *c, char *base) {
 	if (c->proxy)
 		xmlAddTN(root, "proxy", c->proxy);
 	if (c->proxyuser) {
-		node = xmlNewChild(root, NULL, "proxyauth", NULL);
+		node = xmlNewChild(root, NULL, BAD_CAST "proxyauth", NULL);
 		xmlAddTN(node, "username", c->proxyuser);
 		xmlAddTN(node, "password", c->proxypass);
 	}
@@ -405,7 +406,7 @@ conf_write(Configuration *c, char *base) {
 
 #ifdef HAVE_GTK
 	if (app.quiet_dlgs) {
-		xmlNodePtr xmlList = xmlNewChild(root, NULL, "quiet_dlgs", NULL);
+		xmlNodePtr xmlList = xmlNewChild(root, NULL, BAD_CAST "quiet_dlgs", NULL);
 		for (l = app.quiet_dlgs; l != NULL; l = l->next) {
 			xmlAddTN(xmlList, "quiet_dlg", (char*)l->data);
 		}
@@ -418,8 +419,8 @@ conf_write(Configuration *c, char *base) {
 			c->defaultsecurity.type = LJ_SECURITY_PRIVATE;
 		lj_security_to_strings(&c->defaultsecurity, &type, NULL);
 		if (type) {
-			node = xmlNewChild(root, NULL, "defaultsecurity", NULL);
-			xmlSetProp(node, "type", type);
+			node = xmlNewChild(root, NULL, BAD_CAST "defaultsecurity", NULL);
+			xmlSetProp(node, BAD_CAST "type", BAD_CAST type);
 			g_free(type);
 		}
 	}
