@@ -1,8 +1,7 @@
 /* logjam - a GTK client for LiveJournal.
- * Copyright (C) 2000-2002 Evan Martin <evan@livejournal.com>
+ * Copyright (C) 2000-2003 Evan Martin <evan@livejournal.com>
  *
  * vim: tabstop=4 shiftwidth=4 noexpandtab :
- * $Id: datesel.h,v 1.2 2002/11/28 03:09:28 martine Exp $
  */
 
 #ifndef datesel_h
@@ -17,8 +16,10 @@ typedef struct _DateSel      DateSel;
 GType      datesel_get_type(void);
 GtkWidget* datesel_new(void);
 
-void datesel_get_tm(DateSel *ds, struct tm *ptm);
-void datesel_set_tm(DateSel *ds, struct tm *ptm);
+void     datesel_get_tm(DateSel *ds, struct tm *ptm);
+void     datesel_set_tm(DateSel *ds, struct tm *ptm);
+gboolean datesel_get_backdated(DateSel *ds);
+void     datesel_set_backdated(DateSel *ds, gboolean backdated);
 
 #endif /* datesel_h */
 
