@@ -20,7 +20,7 @@
 
 #include "network.h"
 #include "conf.h"
-#include "util.h"
+#include "util-gtk.h"
 #include "spawn.h"
 #include "account.h"
 #include "friends.h"
@@ -842,11 +842,11 @@ friendsui_destroy_cb(GtkWidget *w, JamFriendsUI *fui) {
 	g_slist_foreach(fui->friends, (GFunc)lj_friend_free, NULL);
 	g_slist_free(fui->friends);
 
-	unref_and_null(fui->pb_user);
-	unref_and_null(fui->pb_comm);
-	unref_and_null(fui->pb_larrow);
-	unref_and_null(fui->pb_rarrow);
-	unref_and_null(fui->pb_lrarrow);
+	UNREF_AND_NULL(fui->pb_user);
+	UNREF_AND_NULL(fui->pb_comm);
+	UNREF_AND_NULL(fui->pb_larrow);
+	UNREF_AND_NULL(fui->pb_rarrow);
+	UNREF_AND_NULL(fui->pb_lrarrow);
 }
 
 static GtkWidget*
@@ -983,8 +983,8 @@ friends_manager_show(GtkWindow *mainwin, JamAccountLJ *acc) {
 }
 
 static void
-export_do(JamFriendsUI *fui, GtkFileSelection *fsel) {
-	const char *filename = gtk_file_selection_get_filename(fsel);
+export_do(JamFriendsUI *fui, GtkFileChooser *fsel) {
+	const char *filename = gtk_file_chooser_get_filename(fsel);
 	FILE *fout;
 	LJFriend *f;
 	GSList *l;
@@ -1007,7 +1007,7 @@ export_do(JamFriendsUI *fui, GtkFileSelection *fsel) {
 }
 
 static void
-suggest_cb(GtkWidget *w, GtkWidget *entry) {
+suggest_cb(GtkWidget *w, GtkFileChooser *fsel) {
 	char buf[50];
 	time_t curtime;
 	struct tm *date;
@@ -1018,7 +1018,7 @@ suggest_cb(GtkWidget *w, GtkWidget *entry) {
 	sprintf(buf, "friends.%04d-%02d-%02d", 
 			date->tm_year+1900, date->tm_mon+1, date->tm_mday);
 
-	gtk_entry_set_text(GTK_ENTRY(entry), buf);
+	gtk_file_chooser_set_filename(fsel, buf);
 }
 
 static void
@@ -1026,18 +1026,22 @@ export_cb(JamFriendsUI *fui) {
 	GtkWidget *fsel;
 	GtkWidget *bstamp;
 
-	fsel = jam_filesel_new(_("Select output file"), GTK_WINDOW(fui));
+	fsel = gtk_file_chooser_dialog_new(_("Select output file"), GTK_WINDOW(fui),
+			GTK_FILE_CHOOSER_ACTION_SAVE,
+			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+			GTK_STOCK_SAVE, GTK_RESPONSE_ACCEPT,
+			NULL);
 
 	bstamp = gtk_button_new_with_label(_("  Suggest Filename  "));
-	gtk_box_pack_start(GTK_BOX(GTK_FILE_SELECTION(fsel)->action_area),
-			bstamp, FALSE, FALSE, 0);
+
+	gtk_widget_show(bstamp);
+	gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(fsel), bstamp);
 	g_signal_connect(G_OBJECT(bstamp), "clicked",
 			G_CALLBACK(suggest_cb), 
-			GTK_FILE_SELECTION(fsel)->selection_entry);
-	gtk_widget_show(bstamp);
+			GTK_FILE_CHOOSER(fsel));
 
-	if (gtk_dialog_run(GTK_DIALOG(fsel)) == GTK_RESPONSE_OK)
-		export_do(fui, GTK_FILE_SELECTION(fsel));
+	if (gtk_dialog_run(GTK_DIALOG(fsel)) == GTK_RESPONSE_ACCEPT)
+		export_do(fui, GTK_FILE_CHOOSER(fsel));
 	gtk_widget_destroy(fsel);
 }
 
