@@ -5,12 +5,13 @@
  */
 
 #include "config.h"
+
+#include <glib/gi18n.h>
 #include <gtk/gtkiconfactory.h>
 #include <gtk/gtkwindow.h>
 #include <gtk/gtkstock.h>
 
 #include "icons.h"
-#include "util.h"
 #include "../images/pixbufs.h"
 
 static GtkStockItem logjam_stock_items[] = {
