@@ -4,14 +4,14 @@
  * vim: tabstop=4 shiftwidth=4 noexpandtab :
  */
 
-#include "gtk-all.h"
-
 #include "config.h"
 
+#include "gtk-all.h"
+
 #ifdef HAVE_GTKSPELL
 #include <gtkspell/gtkspell.h>
 #endif /* HAVE_GTKSPELL */
-#include "util.h"
+#include "util-gtk.h"
 #include "jamdoc.h"
 #include "music.h"
 #include "undo.h"
@@ -42,6 +42,9 @@ struct _JamView {
 	GtkWidget *musicbar;
 	GtkWidget *musicbutton, *music;
 
+	GtkWidget *tagsbar;
+	GtkWidget *tags;
+
 	GtkWidget *entry;
 
 	GtkWidget *optionbar;
@@ -405,6 +408,39 @@ music_store(JamView *view) {
 	jam_doc_set_music(view->doc, music);
 }
 
+static void
+tags_add(JamView *view) {
+	view->tags = gtk_entry_new();
+	view->tagsbar = labelled_box_new_sg(_("_Tags:"), view->tags, view->sizegroup);
+	gtk_box_pack_start(GTK_BOX(view), view->tagsbar, FALSE, FALSE, 0);
+	gtk_box_reorder_child(GTK_BOX(view), view->tagsbar, view->musicbar ? 2 : 1);
+	gtk_widget_show_all(view->tagsbar);
+}
+static void
+tags_remove(JamView *view) {
+	jam_doc_set_taglist(view->doc, NULL);
+	gtk_widget_destroy(view->tagsbar);
+	view->tagsbar = view->tags = NULL;
+}
+static gboolean
+tags_visible(JamView *view) {
+	return view->tagsbar != NULL;
+}
+static void
+tags_load(JamView *view) {
+	const char *tags = jam_doc_get_taglist(view->doc);
+	if (tags)
+		show_meta(view, JAM_VIEW_TAGS);
+	if (tags_visible(view))
+		gtk_entry_set_text(GTK_ENTRY(view->tags), tags ? tags : "");
+}
+static void
+tags_store(JamView *view) {
+	const char *tags = gtk_entry_get_text(GTK_ENTRY(view->tags));
+	if (tags[0] == 0) tags = NULL;
+	jam_doc_set_taglist(view->doc, tags);
+}
+
 
 static void
 option_add(JamView *view) {
@@ -529,6 +565,7 @@ static struct {
 	{ "mood",         TRUE, STD(mood),         mood_account_changed     },
 	{ "picture",      TRUE, STD(picture),      picture_account_changed  },
 	{ "music",        TRUE, STD(music),        NULL },
+	{ "tags",         TRUE, STD(tags),         NULL },
 	{ "preformatted", TRUE, STD(preformatted), NULL },
 	{ "datesel",      TRUE, STD(datesel),      NULL },
 	{ "comments",     TRUE, STD(comments),     NULL },
