@@ -4,13 +4,14 @@
  * vim: tabstop=4 shiftwidth=4 noexpandtab :
  */
 
-#include <config.h>
+#include "config.h"
 
-#include <stdlib.h>
 #include "gtk-all.h"
-#include "util.h"
+#include <stdlib.h>
+#include "util-gtk.h"
 #include "account.h"
 
+#include "conf.h"
 #include "tie.h"
 #include "checkfriends.h"
 #include "security.h"
