@@ -79,8 +79,8 @@ menu_make_link(JamWin *jw) {
 }
 static void
 menu_make_journal_link(JamWin *jw) {
-	void link_jam_dialog_run(GtkWindow *win, JamDoc *doc);
-	link_jam_dialog_run(GTK_WINDOW(jw), jw->doc);
+	void link_journal_dialog_run(GtkWindow *win, JamDoc *doc);
+	link_journal_dialog_run(GTK_WINDOW(jw), jw->doc);
 }
 static void
 menu_insert_image(JamWin *jw) {
@@ -105,6 +105,7 @@ load_last_entry(JamWin *jw) {
 
 	jam_doc_load_entry(jw->doc, entry);
 	lj_entry_free(entry);
+	undomgr_reset(UNDOMGR(jam_view_get_undomgr(JAM_VIEW(jw->view))));
 }
 static void
 run_history_recent_dlg(JamWin *jw) { 
@@ -117,6 +118,7 @@ run_history_recent_dlg(JamWin *jw) {
 
 	jam_doc_load_entry(jw->doc, entry);
 	lj_entry_free(entry);
+	undomgr_reset(UNDOMGR(jam_view_get_undomgr(JAM_VIEW(jw->view))));
 }
 
 static void
@@ -131,6 +133,7 @@ run_offline_dlg(JamWin *jw) {
 
 	jam_doc_load_entry(jw->doc, entry);
 	lj_entry_free(entry);
+	undomgr_reset(UNDOMGR(jam_view_get_undomgr(JAM_VIEW(jw->view))));
 }
 
 static void menu_save(JamWin *jw) { jam_save(jw); }
