@@ -5,11 +5,11 @@
  */
 
 #include "config.h"
-#include <glib.h>
+
+#include "glib-all.h"
 
 #include <libxml/nanohttp.h>
 
-#include "util.h"
 #include "conf.h"
 #include "network.h"
 #include "network-internal.h"
