@@ -6,14 +6,13 @@
 
 #include "config.h"
 
-#include <glib.h>
+#include "glib-all.h"
 #include <stdlib.h>
 
 #include <livejournal/livejournal.h>
 #include <livejournal/getchallenge.h>
 
 #include "conf.h"
-#include "util.h"
 #include "network.h"
 #include "network-internal.h"
 
