@@ -265,7 +265,7 @@ move_relative(OfflineUI *oui, int dir) {
 		when_tm.tm_mday = day;
 		
 		found = journal_store_find_relative_by_time(oui->journalstore,
-				timegm(&when_tm), &itemid, dir, NULL);
+				lj_timegm(&when_tm), &itemid, dir, NULL);
 	}
 	if (found)
 		select_entry(oui, itemid);
@@ -395,14 +395,11 @@ make_search(OfflineUI *oui) {
 }
 
 static gboolean
-check_entries_cb(OfflineUI *oui) {
+check_entries(GtkWindow *parent, JamAccount *acc) {
 	GtkWidget *dlg;
 	int res;
 
-	if (journal_store_get_count(oui->journalstore) > 0)
-		return FALSE;
-
-	dlg = gtk_message_dialog_new(GTK_WINDOW(oui), GTK_DIALOG_MODAL,
+	dlg = gtk_message_dialog_new(parent, GTK_DIALOG_MODAL,
 			GTK_MESSAGE_INFO, GTK_BUTTONS_NONE,
 			_("LogJam has no offline entries for this journal. "
 				"You must first synchronize this journal to your local "
@@ -413,9 +410,8 @@ check_entries_cb(OfflineUI *oui) {
 			NULL);
 	res = gtk_dialog_run(GTK_DIALOG(dlg));
 	gtk_widget_destroy(dlg);
-	if (res == GTK_RESPONSE_OK) {
-		sync_run(JAM_ACCOUNT_LJ(journal_store_get_account(oui->journalstore)), GTK_WINDOW(oui));
-	}
+	if (res == GTK_RESPONSE_OK)
+		return sync_run(JAM_ACCOUNT_LJ(acc), parent);
 	return FALSE;
 }
 
@@ -512,8 +508,6 @@ offlineui_init(GTypeInstance *instance, gpointer g_class) {
 	selection_changed_cb(gtk_tree_view_get_selection(GTK_TREE_VIEW(oui->list)),
 			oui);
 	geometry_tie(GTK_WIDGET(oui), GEOM_OFFLINE);
-
-	gtk_idle_add((GtkFunction)check_entries_cb, oui);
 }
 
 static void
@@ -607,7 +601,7 @@ offline_jump_to_online(OfflineUI *oui) {
 static void
 offline_copy_link(OfflineUI *oui) {
 	gchar *url = offline_current_entry_link(oui);
-	if (*url != '\0')
+	if (url && *url != '\0')
 		gtk_clipboard_set_text(gtk_clipboard_get(GDK_SELECTION_CLIPBOARD),
 				url, -1 /* determine length automatically */);
 	g_free(url);
@@ -615,12 +609,20 @@ offline_copy_link(OfflineUI *oui) {
 
 LJEntry*
 offline_dlg_run(GtkWindow *parent, JamAccount *acc) {
+	JournalStore *js = NULL;
 	GtkWidget *oui;
 	LJEntry *entry = NULL;
 	gboolean run = TRUE;
 
+	while (js == NULL) {
+		js = journal_store_open(acc, FALSE, NULL);
+		if (js == NULL)
+			if (!check_entries(parent, acc))
+				return NULL;
+	}
+
 	oui = offlineui_new();
-	OFFLINEUI(oui)->journalstore = journal_store_open(acc, FALSE, NULL);
+	OFFLINEUI(oui)->journalstore = js;
 	OFFLINEUI(oui)->account = acc;
 	month_changed_cb(GTK_CALENDAR(OFFLINEUI(oui)->cal), OFFLINEUI(oui));
 	day_selected_cb (GTK_CALENDAR(OFFLINEUI(oui)->cal), OFFLINEUI(oui));
@@ -640,7 +642,9 @@ offline_dlg_run(GtkWindow *parent, JamAccount *acc) {
 			default:
 				run = FALSE;
 		}
-	} gtk_widget_destroy(oui);
+	}
+	
+	gtk_widget_destroy(oui);
 
 	return entry;
 }
