@@ -4,7 +4,6 @@
  * vim: tabstop=4 shiftwidth=4 noexpandtab :
  */
 
-#include <glib.h>
 #include "gtk-all.h"
 #include <stdlib.h> /* atoi */
 
@@ -12,7 +11,7 @@
 #include "jam.h"
 #include "poll.h"
 #include "pollcreator.h"
-#include "util.h"
+#include "util-gtk.h"
 
 typedef struct _PollDlg PollDlg;
 
