@@ -12,7 +12,7 @@
 
 #include "conf.h"
 #include "security.h"
-#include "util.h"
+#include "util-gtk.h"
 #include "spawn.h"
 #include "jam.h"
 #include "checkfriends.h"
