@@ -176,12 +176,12 @@ sync_run_gtk(JamAccountLJ *acc, gpointer parent) {
 	SyncStatus st = {0}, *status = &st;
 	GSList *warnings = NULL;
 	GError *err = NULL;
-	gboolean ret = TRUE;
+	gboolean success;
 
 	status->account = acc;
 
 	sync_init_gtk(status, parent);
-	sync_run_internal(status, sync_run_verb_gtk, sync_progress_gtk,
+	success = sync_run_internal(status, sync_run_verb_gtk, sync_progress_gtk,
 			parent, &warnings, &err);
 
 	if (warnings) {
@@ -193,13 +193,13 @@ sync_run_gtk(JamAccountLJ *acc, gpointer parent) {
 	if (err) {
 		progress_window_show_error(PROGRESS_WINDOW(status->progresswin), err->message);
 		g_error_free(err);
-		ret = FALSE;
+		success = FALSE;
 	}
 
 	if (status->progresswin)
 		gtk_widget_destroy(status->progresswin);
 
-	return ret;
+	return success;
 }
 
 #endif /* HAVE_GTK */
@@ -240,6 +240,7 @@ sync_run_cli(JamAccountLJ *acc) {
 	GSList *warnings = NULL, *l;
 	GError *err = NULL;
 	char *id;
+	gboolean success;
 
 	status->account = acc;
 	id = jam_account_id_strdup(JAM_ACCOUNT(status->account));
@@ -247,7 +248,7 @@ sync_run_cli(JamAccountLJ *acc) {
 	g_print("\n");
 	g_free(id);
 
-	sync_run_internal(status, sync_run_verb_cli, sync_progress_cli, NULL, &warnings, &err);
+	success = sync_run_internal(status, sync_run_verb_cli, sync_progress_cli, NULL, &warnings, &err);
 
 	if (warnings) {
 		g_print(_("Warnings:\n"));
@@ -259,9 +260,9 @@ sync_run_cli(JamAccountLJ *acc) {
 	if (err) {
 		g_print(_("Error: %s\n"), err->message);
 		g_error_free(err);
-		return FALSE;
+		success = FALSE;
 	}
-	return TRUE;
+	return success;
 }
 
 static gboolean
